@@ -13,11 +13,16 @@ import utils.object_utils as obj
 import utils.sql_utils as sqlUtils
 import utils.table_utils as tableUtils
 import utils.generation as genUtils
+import utils.DatabaseManager as databaseManager
+# import utils.local_db_management as local
 
 # pylint: disable=missing-function-docstring
 # pylint: disable=missing-class-docstring
 # pylint: disable=invalid-name
 
+def database():
+    return databaseManager.DatabaseManager()
+
 def new_database():
     return ColemenDatabase()
 
@@ -240,6 +245,8 @@ class ColemenDatabase:
 
     def close(self):
         self.con.close()
+        self.con = None
+        self.cur = None
 
     def execute_single_statement(self, sql, args=False):
         '''
@@ -268,7 +275,9 @@ class ColemenDatabase:
             `method_name`: execute_single_statement
         '''
         success = False
-
+        if self.cur is None or self.con is None:
+            print("Not connected to a database, aborting query.")
+            return False
         try:
             if args is False:
                 # print(f"executing sql: ",sql)
