@@ -1,9 +1,13 @@
+
 import json
 import colemen_file_utils as cfu
 import utils.object_utils as obj
-
+import colemen_string_utils as csu
 # pylint: disable=missing-function-docstring
 # pylint: disable=missing-class-docstring
+# pylint: disable=missing-function-docstring
+# pylint: disable=invalid-name
+# pylint: disable=line-too-long
 
 class table_utils:
     def __init__(self, db):
@@ -212,7 +216,7 @@ class table_utils:
             Arguments
             -------------------------
             `table_name` {string}
-                    The name of the table to query
+                The name of the table to query
 
             Return {list}
             ----------------------
@@ -227,13 +231,52 @@ class table_utils:
             `method_name`: __mysql_get_column_array
         '''
         col_names = []
-        self._db.run(f"PRAGMA table_info({table_name})")
+        self._db.run(f"desc {table_name};")
+        # self._db.run(f"PRAGMA table_info({table_name})")
         res = self._db.cur.fetchall()
+        # print(f"res:{res}")
         for column in res:
-            col_names.append(column['name'])
+            col_names.append(column['Field'])
             # print(a['name'])
         return col_names
 
+    def format_table_name(self,name):
+        '''
+            Formats a table name so that it is wrapped in accents 
+            and the schema is separated by a period if present.
+
+            ----------
+
+            Arguments
+            -------------------------
+            `name` {string}
+                The table name (and schema) to format.
+
+            Return {string,boolean}
+            ----------------------
+            The formatted string if successful, False otherwise
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 04\\10\\2022 13:32:03
+            `memberOf`: table_utils
+            `version`: 1.0
+            `method_name`: format_table_name
+            # @TODO []: documentation for format_table_name
+        '''
+        name = csu.format.strip_any(name,["`",'"',"'"])
+        name_list = name.split(".")
+        output_name = []
+        for n in name_list:
+            if len(n) > 0:
+                output_name.append(f"`{n}`")
+        if len(output_name) > 1:
+            return '.'.join(output_name)
+        if len(output_name) == 1:
+            return output_name[0]
+        return False
+
     def get_column_data_array(self, table_name):
         '''
             Gets all data for each column in the table specified.
